pub struct PendingIntentPlan {
pub operation_ids: Vec<OperationId>,
pub immutable_sent: BTreeSet<OperationId>,
pub digest: [u8; 32],
}Expand description
Payload-free commitment to pending intent preserved across activation.
Fields
operation_ids: Vec<OperationId>immutable_sent: BTreeSet<OperationId>digest: [u8; 32]Implementations
Sourceimpl PendingIntentPlan
impl PendingIntentPlan
Sourcepub fn build(
operation_ids: Vec<OperationId>,
immutable_sent: BTreeSet<OperationId>,
) -> Result<Self, BootstrapError>
pub fn build( operation_ids: Vec<OperationId>, immutable_sent: BTreeSet<OperationId>, ) -> Result<Self, BootstrapError>
Sorts identities, rejects duplicate declarations, and calculates a restart-stable digest.
Errors
Returns an error when a sent identity is absent or an identity is duplicated.